@@ -1,14 +1,23 @@
 package Test::Routine::Runner;
-{
-  $Test::Routine::Runner::VERSION = '0.015';
-}
-use Moose;
 # ABSTRACT: tools for running Test::Routine tests
+$Test::Routine::Runner::VERSION = '0.020';
+use Moose;
 
+#pod =head1 OVERVIEW
+#pod
+#pod A Test::Routine::Runner takes a callback for building test instances, then uses
+#pod it to build instances and run the tests on it.  The Test::Routine::Runner
+#pod interface is still undergoing work, but the Test::Routine::Util exports for
+#pod running tests, descibed in L<Test::Routine|Test::Routine/Running Tests>, are
+#pod more stable.  Please use those instead, unless you are willing to deal with
+#pod interface breakage.
+#pod
+#pod =cut
 
-use Carp qw(confess);
+use Carp qw(confess croak);
 use Scalar::Util qw(reftype);
 use Test::More ();
+use Try::Tiny;
 
 use Moose::Util::TypeConstraints;
 
@@ -83,6 +92,14 @@ sub run {
   my @tests = grep { Moose::Util::does_role($_, 'Test::Routine::Test::Role') }
               $thing->meta->get_all_methods;
 
+  my $re = $ENV{TEST_METHOD};
+  if (defined $re and length $re) {
+    my $filter = try { qr/$re/ } # compile the the regex separately ...
+        catch { croak("TEST_METHOD ($re) is not a valid regular expression: $_") };
+    $filter = qr/\A$filter\z/;  # ... so it can't mess with the anchoring
+    @tests = grep { $_->description =~ $filter } @tests;
+  }
+
   # As a side note, I wonder whether there is any way to format the code below
   # to not look stupid. -- rjbs, 2010-09-28
   my @ordered_tests = sort {
@@ -101,15 +118,18 @@ sub run {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::Routine::Runner - tools for running Test::Routine tests
 
 =head1 VERSION
 
-version 0.015
+version 0.020
 
 =head1 OVERVIEW
 
@@ -132,4 +152,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
